@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2003-2006 by the gtk2-perl team (see the file AUTHORS for
+# Copyright (C) 2003-2005 by the gtk2-perl team (see the file AUTHORS for
 # the full list)
 # 
 # This library is free software; you can redistribute it and/or modify it under
@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.84.2.4 2006/02/05 15:31:00 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.86 2005/10/18 17:09:29 kaffeetisch Exp $
 #
 
 package Gtk2;
@@ -29,9 +29,12 @@ use warnings;
 
 use Glib;
 
+# Optionally "depend" on Cairo.
+eval "use Cairo;";
+
 require DynaLoader;
 
-our $VERSION = '1.104';
+our $VERSION = '1.110';
 
 our @ISA = qw(DynaLoader);
 
@@ -214,7 +217,7 @@ The gtk2-perl team:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003-2006 by the gtk2-perl team.
+Copyright 2003-2005 by the gtk2-perl team.
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
