@@ -18,13 +18,15 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  * 
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.37 2005/07/11 22:39:12 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.38 2005/09/29 22:37:15 kaffeetisch Exp $
  */
 
 #ifndef _GTK2PERL_H_
 #define _GTK2PERL_H_
 
 #include <gperl.h>
+#include <atk/atk.h>
+#include <atk/atk-enum-types.h>
 #include <gtk/gtk.h>
 
 #include "gtk2perl-versions.h"
